"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.doToots = exports.doToot = exports.postToot = void 0;
const promises_1 = require("fs/promises");
const promises_2 = require("timers/promises");
const crypto_1 = require("crypto");
const masto_1 = require("masto");
const async_retry_1 = __importDefault(require("async-retry"));
const util_1 = require("./util");
async function postToot(status, client, inReplyToId) {
    const s = typeof status === "string" ? { status } : status;
    const mediaIds = [];
    if (s.media) {
        for (const m of s.media) {
            // form-data really doesn't like when fields are declared but undefined,
            // so we add them explicitly one-by-one.
            const config = {};
            if ("caption" in m) {
                config["caption"] = m.caption;
            }
            if ("focus" in m) {
                config["focus"] = m.focus;
            }
            const data = "buffer" in m ? m.buffer : await (0, promises_1.readFile)(m.path);
            // @ts-expect-error Blob not available in node <18, see
            // https://github.com/neet/masto.js/issues/813#issuecomment-1382606868
            const file = "Blob" in global ? new Blob([data]) : data;
            const { id } = await client.v2.mediaAttachments.create({
                file,
                ...config,
            });
            mediaIds.push(id);
        }
    }
    await Promise.all(mediaIds.map((id) => client.v2.mediaAttachments.waitFor(id)));
    const idempotencyKey = (0, crypto_1.randomUUID)();
    const publishedToot = await (0, async_retry_1.default)(() => client.v1.statuses.create({
        status: s.status,
        visibility: s.visibility ?? "public",
        inReplyToId,
        mediaIds,
    }, { idempotencyKey }), { retries: 5 });
    return publishedToot;
}
exports.postToot = postToot;
async function doToot(status, apiConfig) {
    const client = await (0, async_retry_1.default)(() => (0, masto_1.login)({
        url: apiConfig.server,
        accessToken: apiConfig.token,
        timeout: 30000,
    }));
    return postToot(status, client);
}
exports.doToot = doToot;
async function doToots(statuses, apiConfig) {
    const client = await (0, async_retry_1.default)(() => (0, masto_1.login)({
        url: apiConfig.server,
        accessToken: apiConfig.token,
        timeout: 30000,
    }));
    const postedStatuses = [];
    for (let i = 0; i < statuses.length; i++) {
        const inReplyToId = i > 0 ? postedStatuses[i - 1].id : undefined;
        postedStatuses.push(await postToot(statuses[i], client, inReplyToId));
        if (i < statuses.length - 1) {
            await (0, promises_2.setTimeout)(util_1.WAIT_TIME_BETWEEN_REPLIES);
        }
    }
    return postedStatuses;
}
exports.doToots = doToots;
//# sourceMappingURL=toot.js.map