"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.doTweets = exports.doTweet = exports.postTweet = void 0;
const promises_1 = require("fs/promises");
const promises_2 = require("timers/promises");
const twitter_api_client_1 = require("twitter-api-client");
const async_retry_1 = __importDefault(require("async-retry"));
const util_1 = require("./util");
async function postTweet(status, client, inReplyToId) {
    const s = typeof status === "string" ? { status } : status;
    const mediaIds = [];
    if (s.media) {
        for (const m of s.media) {
            // the twitter client doesn't seem to let us stream the buffer directly
            const buffer = "buffer" in m ? m.buffer : await (0, promises_1.readFile)(m.path);
            const { media_id_string } = await client.media.mediaUpload({
                media_data: buffer.toString("base64"),
            });
            mediaIds.push(media_id_string);
            if (m.caption) {
                await client.media.mediaMetadataCreate({
                    media_id: media_id_string,
                    alt_text: { text: m.caption },
                });
            }
        }
    }
    const publishedTweet = await (0, async_retry_1.default)(() => client.tweets.statusesUpdate({
        status: s.status,
        in_reply_to_status_id: inReplyToId,
        auto_populate_reply_metadata: true,
        media_ids: mediaIds.length > 0 ? mediaIds.join(",") : undefined,
    }), { retries: 5 });
    return publishedTweet;
}
exports.postTweet = postTweet;
async function doTweet(status, apiConfig) {
    const client = new twitter_api_client_1.TwitterClient({
        apiKey: apiConfig.apiKey,
        apiSecret: apiConfig.apiSecret,
        accessToken: apiConfig.accessToken,
        accessTokenSecret: apiConfig.accessSecret,
        disableCache: true,
    });
    return postTweet(status, client);
}
exports.doTweet = doTweet;
async function doTweets(statuses, apiConfig) {
    const client = new twitter_api_client_1.TwitterClient({
        apiKey: apiConfig.apiKey,
        apiSecret: apiConfig.apiSecret,
        accessToken: apiConfig.accessToken,
        accessTokenSecret: apiConfig.accessSecret,
        disableCache: true,
    });
    const postedStatuses = [];
    for (let i = 0; i < statuses.length; i++) {
        const inReplyToId = i > 0 ? postedStatuses[i - 1].id_str : undefined;
        postedStatuses.push(await postTweet(statuses[i], client, inReplyToId));
        if (i < statuses.length - 1) {
            await (0, promises_2.setTimeout)(util_1.WAIT_TIME_BETWEEN_REPLIES);
        }
    }
    return postedStatuses;
}
exports.doTweets = doTweets;
//# sourceMappingURL=tweet.js.map